@@ -49,7 +49,7 @@ def docker_push_optimized(image_name: DockerCompleteImageName) -> DockerComplete
     # logger.debug(f"RepoTags {RepoTags}")
     # logger.debug(f"RepoDigests {RepoDigests}")
 
-    if RepoDigests and (not "DT_FORCE_PUSH" in os.environ):
+    if RepoDigests and ("DT_PUSH_OPT" in os.environ):
         logger.debug(f"RepoDigests already present; skipping pushing: {RepoDigests}")
         return RepoDigests[0]
     digest_from_push = docker_push_retry(client, image_name)
